@@ -74,6 +74,8 @@ def get_mappings(schemas=None, schema_info=False):
                 field_mapping = CATALOG_TYPES[catalog_type].copy()
             if "store" in catalog_info:
                 field_mapping["store"] = catalog_info["store"]
+            if "analyzer" in catalog_info:
+                field_mapping["analyzer"] = catalog_info["analyzer"]
             if schema_info:
                 if "_schemas" not in field_mapping:
                     field_mapping["_schemas"] = []
@@ -100,4 +102,7 @@ Registered mapping: {field_mapping}
 
             schema_field_mappings[index_name] = catalog_info["__schema__"]
             mappings[index_name] = field_mapping
-    return {"properties": mappings}
+    return {
+        "properties": mappings,
+        "dynamic": app_settings.get("elasticsearch", {}).get("dynamic_mapping", False),
+    }
